<?php

/**
 * @file
 * A checkout pane plugin for Ubercart.
 */
/**
 * Define this checkout paneI plugin.
 */
$plugin = array(
  'id' => 'deposit',
  'callback' => 'uc_checkout_pane_deposit',
  'title' => t('预付款余额抵扣'),
  'desc' => t('在结算过程中，允许用户使用预付款余额.'),
  'weight' => 6,
  'process' => TRUE,
);

/**
 * Checkout Pane callback function.
 *
 * Used to display a form in the checkout process.
 */
function uc_checkout_pane_deposit($op, $order, $form = NULL, &$form_state = NULL) {
  global $user;
  if ($user->uid ==0) {
    return;
  }
  switch ($op) {
    case 'view':
      $current_deposit = uc_deposit_get_user_current_deposit($user->uid);
      //如果为空,直接返回.
      if (empty($current_deposit)) {
        return;
      }
      $description = t('请输入您要使用的预付款金额，如果您的余额大于订单总额，那么您可以再下面直接选择预付款支付.');
      $contents['current_deposit'] = array(
        '#markup' => t('当前可用余额：') . $current_deposit,
        '#weight' => -10,
      );
      $contents['deposit'] = array(
        '#type' => 'textfield',
        '#title' => t('预付款'),
        '#default_value' => isset($order->data['deposit']) ? $order->data['deposit'] : '',
        '#size' => 25,
        '#weight' => 0,
      );
      return array('description' => $description, 'contents' => $contents);

    case 'process':
	   //var_export($form);
      if (isset($form_state['values']['panes']['deposit']['deposit'])) {
        $order->data['deposit'] = $form_state['values']['panes']['deposit']['deposit'];
        $current_deposit = uc_deposit_get_user_current_deposit($user->uid);
        //$coupon = uc_coupon_validate($arg1->data['deposit']);
        if ($order->data['deposit'] > $current_deposit) {
          //drupal_set_message(t('所用的预付款超过了最大限额'), 'error');
          form_set_error('panes][deposit][deposit', t('所用的预付款超过了最大限额'));
          return FALSE;
        }
        _uc_deposit_apply_to_order($order->order_id, $order->data['deposit']);
      }
      return TRUE;
  }
}

/**
 * Create or update the coupon line item in an order.
 */
function _uc_deposit_apply_to_order($order_id, $deposit) {
  $lid = db_query("SELECT line_item_id FROM {uc_order_line_items} WHERE order_id = :order_id AND type = 'deposit'", array(':order_id' => $order_id))->fetchField();
  if ($lid) {
    //根据order_id获得uc_deposit的序列号
    $txn_id = db_query("SELECT txn_id FROM {uc_deposit_orders} WHERE oid = :oid", array(':oid' => $order_id))->fetchField();
    //更新uc_deposit中对应记录的deposit值，以及修改时间
    $sql = "UPDATE {uc_deposit} SET deposit = :deposit, changed = :changed WHERE txn_id = :txn_id";
    $current_time = time();
    db_query($sql, array(':deposit' => -$deposit, ':changed' => $current_time, ':txn_id' => $txn_id));
    //更新uc_deposit_orders中对应记录的deposit值
    db_query("UPDATE {uc_deposit_orders} SET deposit = :deposit WHERE oid = :oid", array(':deposit' => -$deposit, ':oid' => $order_id));
    uc_order_update_line_item($lid, t('预付款'), -$deposit);
  }
  else {
    //向uc_deposit中插入一个deposit记录
    $sql = "INSERT INTO {uc_deposit} (uid, deposit, time_stamp, changed, description) VALUES(:uid, :deposit, :time_stamp, :changed, :description)";
    $current_time = time();
    global $user;
    $txn_id = db_query($sql, array(':uid' => $user->uid, ':deposit' => -$deposit, ':time_stamp' => $current_time, ':changed' => $current_time, ':description' => t('在订单(ID:@order_id)结算中使用预付款', array('@order_id' => $order_id))), array('return' => Database::RETURN_INSERT_ID));
    //获取序列号ID
    //$txn_id = db_last_insert_id('uc_deposit', 'txn_id');
	//$txn_id = db_query("SELECT 1", array(), array('return' => Database::RETURN_INSERT_ID));
    //向uc_deposit_orders中插入一个deposit记录
    db_query("INSERT INTO {uc_deposit_orders} (txn_id, oid, deposit) VALUES (:txn_id, :oid, :deposit)", array(':txn_id' => $txn_id, ':oid' => $order_id, ':deposit' => -$deposit));
    //添加一个预付款行项
    uc_order_line_item_add($order_id, 'deposit', t('预付款'), -$deposit);
  }
}
