<?php

/**
 * @file
 * 实现预付款支付的管理页面.
 * zhupou.cn制作
 */

function uc_deposit_admin_deposit() {
  $header = array(
    array('data' => t('用户'), 'field' => 'u.name'),
    array('data' => t('预存款'), 'field' => 'd.deposit'),
    array('data' => t('描述'), 'field' => 'd.description'),
    array('data' => t('时间'), 'field' => 'd.changed'),
    array('data' => t('编辑'), 'field' => 'd.txn_id'),
  );
  
  $query = db_select('uc_deposit', 'd')->extend('PagerDefault')->extend('TableSort')
    ->fields('d', array('txn_id', 'uid', 'deposit', 'changed', 'description'))
    ->fields('u', array('name'))
    ->groupBy('d.uid')
    ->groupBy('u.name')
    ->groupBy('d.deposit')
    ->groupBy('d.txn_id')
    ->orderByHeader($header)
    ->limit(30);

  $query->join('users', 'u', 'd.uid = u.uid'); 
  $result = $query->execute();
  $rows = array();
  foreach ($result as $data) {
    $rows[$data->txn_id] = array(
      'name' => l($data->name, "user/$data->uid"),
      'deposit' => $data->deposit,
      'description' => $data->description,
      'changed' => format_date($data->changed, 'custom', 'Y-m-d H:i:s'),
      'txn_id' => l(t('编辑'), "admin/config/people/deposit/edit/$data->txn_id"),
    );
  }
  
  $output = array();
/*
  $output['list'] = array(
    '#type' => 'container',
    '#id' => 'uc_deposit_list_wrapper',
  );
  $output['list']['table'] = array(
    '#theme' => 'table',
    '#header' => $header,
    '#rows' => $rows,
  );
  $output['list']['pager'] = array(
    '#theme' => 'pager',
  );
  */
  $output['table'] = array(
    '#theme' => 'table',
    '#header' => $header,
    '#rows' => $rows,
  );
  $output['pager'] = array(
    '#theme' => 'pager',
  );
  return $output;
}

function uc_deposit_admin_txn() {
  global $user;
  $mode = arg(4);
  if ($mode == 'edit' && arg(5)) {
    $txn_id = (int)arg(5);
    $txn = db_query('SELECT * FROM {uc_deposit} WHERE txn_id = :txn_id', array(':txn_id' => $txn_id))->fetchObject();
    $timestamp = format_date($txn->time_stamp, 'custom', 'Y-m-d H:i:s');
    $txn_user = user_load($txn->uid);
  }
  elseif ($mode == 'add' && arg(5)) {
    if ($txn) {
      $txn_user = user_load($txn);
    }
  }
  $form['txn_user'] = array(
    '#type'          => 'textfield',
    '#title'         => t('User Name'),
    '#size'          => 30,
    '#maxlength'     => 60,
    '#default_value' => isset($txn_user->name) ? $txn_user->name : '',
    '#autocomplete_path' => $mode == 'edit' ? NULL : 'user/autocomplete',
    '#description'   => t('想为其增加预存款的用户'),
  );
  $form['deposit'] = array(
    '#type'          => 'textfield',
    '#title'         => t('预存款'),
    '#size'          => 10,
    '#maxlength'     => 10,
    '#default_value' => isset($txn->deposit) ? $txn->deposit : '',
    '#description'   => t('要添加的预存款数量（支持负数符号-）,最多保留两位有效数字.'),
    );
  $form['description'] = array(
    '#type'          => 'textarea',
    '#title'         => t('描述'),
    '#default_value' => isset($txn->description) ? $txn->description : '',
    '#width'         => 70,
    '#lines'         => 5,
    '#description'   => t('输入添加预存款的原因.'),
    );

  switch ($mode) {
    case 'edit':
      $form['txn_user']['#disabled'] = TRUE;
      unset($form['txn_user']['#autocomplete_path']);

      $form['txn_uid'] = array(
        '#type'  => 'value',
        '#value' => $txn->uid,
      );
      $form['txn_id'] = array(
        '#type'  => 'value',
        '#value' => $txn_id,
      ); 
      break;
  }

  $form['mode'] = array(
    '#type'  => 'hidden',
    '#default_value' => $mode,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
   );

  return $form;
}
function uc_deposit_admin_txn_validate($form, &$form_state) {
  if (!is_numeric($form_state['values']['deposit'])) {
    form_set_error('deposit', t('预存款必须是一个数字.'));
  }
}
function uc_deposit_admin_txn_submit($form, &$form_state) {
  //$txn_user = user_load(array('name' => $form_state['values']['txn_user']));
  $txn_user = user_load_by_name($form_state['values']['txn_user']);
  drupal_set_message('123'.$form_state['values']['txn_user']);
  $deposit = $form_state['values']['deposit'];
  switch ($form_state['values']['mode']) {
    case 'add':
      $sql = "INSERT INTO {uc_deposit} (uid, deposit, time_stamp, changed, description) VALUES(:uid, :deposit, :time_stamp, :changed, :description)";
      $current_time = time();
      db_query($sql, array(':uid' => $txn_user->uid, ':deposit' => $deposit, ':time_stamp' => $current_time, ':changed' => $current_time, ':description' => $form_state['values']['description']));
      break;
      
    case 'edit':
      $sql = "UPDATE {uc_deposit} SET deposit = :deposit, changed = :changed,  description = :description WHERE txn_id = :txn_id";
      $current_time = time();
      db_query($sql, array(':deposit' => $deposit, ':changed' => $current_time, ':description' => $form_state['values']['description'], ':txn_id' => $form_state['values']['txn_id']));
      break;
  }
  $form_state['redirect'] = 'admin/config/people/deposit';
}